﻿using combit.Reporting;
using combit.Reporting.DataProviders;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Web;

namespace Report.Library
{
    public class ReportBuilder
    {
        private string _baseDirectory;

        public ReportBuilder(string baseDirectory)
        {
            _baseDirectory = baseDirectory;
        }

        public Stream BuildReport(ReportInfo repInfo)
        {
            var stream = GetReportAsStream(repInfo);
            return stream;
        }

        private Stream GetReportAsStream(ReportInfo repInfo)
        {
            MemoryStream stream = new MemoryStream();
            ReportController controller = new ReportController();
            var reportModel = controller.GetReport(repInfo);
            var basedir = AppDomain.CurrentDomain.BaseDirectory;
            string reportFilePath = $@"{basedir}LLReports\" + repInfo.LLReportFile;

            using (ListLabel LL = new ListLabel())
            {
                LL.LicensingInfo = "OUROWN";
                LL.Variables.AddFromObject("info", "Testing LL");
                LL.Variables.AddFromObject("employer", "Employer data");

                //Allows the List and Label preview file to export into different data types
                LL.Core.LlSetOptionString(LlOptionString.EmbeddedExportFormats, "PDF;XLS;DOCX");
                LL.DataSource = new ObjectDataProvider(reportModel);
#if DEBUG
                LL.Debug = LlDebug.Enabled | LlDebug.LogToFile;
                //LL.DebugLogFilePath = @"c:\tmp\ll-server.log";
#endif
                LL.IncrementalPreview = true;

                LlExportTarget exportTarget = LlExportTarget.Preview;
                var streamExportConfiguration = new ExportConfiguration(exportTarget, stream, reportFilePath);
                LL.Export(streamExportConfiguration);

                return stream;
            }
        }
    }
}